==> kubernetes-model-gatewayapi-6.3.1-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/HTTPRouteSpecFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface HTTPRouteSpecFluent<A extends HTTPRouteSpecFluent<A>> extends Fluent<A>{
  public A addToHostnames(Integer index,String item);
  public A setToHostnames(Integer index,String item);
  public A addToHostnames(java.lang.String... items);
  public A addAllToHostnames(Collection<String> items);
  public A removeFromHostnames(java.lang.String... items);
  public A removeAllFromHostnames(Collection<String> items);
  public List<String> getHostnames();
  public String getHostname(Integer index);
  public String getFirstHostname();
  public String getLastHostname();
  public String getMatchingHostname(Predicate<String> predicate);
  public Boolean hasMatchingHostname(Predicate<String> predicate);
  public A withHostnames(List<String> hostnames);
  public A withHostnames(java.lang.String... hostnames);
  public Boolean hasHostnames();
  public A addToParentRefs(Integer index,ParentReference item);
  public A setToParentRefs(Integer index,ParentReference item);
  public A addToParentRefs(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ParentReference... items);
  public A addAllToParentRefs(Collection<ParentReference> items);
  public A removeFromParentRefs(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ParentReference... items);
  public A removeAllFromParentRefs(Collection<ParentReference> items);
  public A removeMatchingFromParentRefs(Predicate<ParentReferenceBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildParentRefs instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ParentReference> getParentRefs();
  public List<ParentReference> buildParentRefs();
  public ParentReference buildParentRef(Integer index);
  public ParentReference buildFirstParentRef();
  public ParentReference buildLastParentRef();
  public ParentReference buildMatchingParentRef(Predicate<ParentReferenceBuilder> predicate);
  public Boolean hasMatchingParentRef(Predicate<ParentReferenceBuilder> predicate);
  public A withParentRefs(List<ParentReference> parentRefs);
  public A withParentRefs(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ParentReference... parentRefs);
  public Boolean hasParentRefs();
  public HTTPRouteSpecFluent.ParentRefsNested<A> addNewParentRef();
  public HTTPRouteSpecFluent.ParentRefsNested<A> addNewParentRefLike(ParentReference item);
  public HTTPRouteSpecFluent.ParentRefsNested<A> setNewParentRefLike(Integer index,ParentReference item);
  public HTTPRouteSpecFluent.ParentRefsNested<A> editParentRef(Integer index);
  public HTTPRouteSpecFluent.ParentRefsNested<A> editFirstParentRef();
  public HTTPRouteSpecFluent.ParentRefsNested<A> editLastParentRef();
  public HTTPRouteSpecFluent.ParentRefsNested<A> editMatchingParentRef(Predicate<ParentReferenceBuilder> predicate);
  public A addToRules(Integer index,HTTPRouteRule item);
  public A setToRules(Integer index,HTTPRouteRule item);
  public A addToRules(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPRouteRule... items);
  public A addAllToRules(Collection<HTTPRouteRule> items);
  public A removeFromRules(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPRouteRule... items);
  public A removeAllFromRules(Collection<HTTPRouteRule> items);
  public A removeMatchingFromRules(Predicate<HTTPRouteRuleBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildRules instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<HTTPRouteRule> getRules();
  public List<HTTPRouteRule> buildRules();
  public HTTPRouteRule buildRule(Integer index);
  public HTTPRouteRule buildFirstRule();
  public HTTPRouteRule buildLastRule();
  public HTTPRouteRule buildMatchingRule(Predicate<HTTPRouteRuleBuilder> predicate);
  public Boolean hasMatchingRule(Predicate<HTTPRouteRuleBuilder> predicate);
  public A withRules(List<HTTPRouteRule> rules);
  public A withRules(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPRouteRule... rules);
  public Boolean hasRules();
  public HTTPRouteSpecFluent.RulesNested<A> addNewRule();
  public HTTPRouteSpecFluent.RulesNested<A> addNewRuleLike(HTTPRouteRule item);
  public HTTPRouteSpecFluent.RulesNested<A> setNewRuleLike(Integer index,HTTPRouteRule item);
  public HTTPRouteSpecFluent.RulesNested<A> editRule(Integer index);
  public HTTPRouteSpecFluent.RulesNested<A> editFirstRule();
  public HTTPRouteSpecFluent.RulesNested<A> editLastRule();
  public HTTPRouteSpecFluent.RulesNested<A> editMatchingRule(Predicate<HTTPRouteRuleBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ParentRefsNested<N> extends Nested<N>,ParentReferenceFluent<HTTPRouteSpecFluent.ParentRefsNested<N>>{
    public N and();
    public N endParentRef();
    
  }
  public interface RulesNested<N> extends Nested<N>,HTTPRouteRuleFluent<HTTPRouteSpecFluent.RulesNested<N>>{
    public N and();
    public N endRule();
    
  }
  
}

==> kubernetes-model-gatewayapi-6.7.0-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/HTTPRouteSpecFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface HTTPRouteSpecFluent<A extends HTTPRouteSpecFluent<A>> extends Fluent<A>{
  public A addToHostnames(int index,String item);
  public A setToHostnames(int index,String item);
  public A addToHostnames(java.lang.String... items);
  public A addAllToHostnames(Collection<String> items);
  public A removeFromHostnames(java.lang.String... items);
  public A removeAllFromHostnames(Collection<String> items);
  public List<String> getHostnames();
  public String getHostname(int index);
  public String getFirstHostname();
  public String getLastHostname();
  public String getMatchingHostname(Predicate<String> predicate);
  public Boolean hasMatchingHostname(Predicate<String> predicate);
  public A withHostnames(List<String> hostnames);
  public A withHostnames(java.lang.String... hostnames);
  public Boolean hasHostnames();
  public A addToParentRefs(int index,ParentReference item);
  public A setToParentRefs(int index,ParentReference item);
  public A addToParentRefs(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ParentReference... items);
  public A addAllToParentRefs(Collection<ParentReference> items);
  public A removeFromParentRefs(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ParentReference... items);
  public A removeAllFromParentRefs(Collection<ParentReference> items);
  public A removeMatchingFromParentRefs(Predicate<ParentReferenceBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildParentRefs instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ParentReference> getParentRefs();
  public List<ParentReference> buildParentRefs();
  public ParentReference buildParentRef(int index);
  public ParentReference buildFirstParentRef();
  public ParentReference buildLastParentRef();
  public ParentReference buildMatchingParentRef(Predicate<ParentReferenceBuilder> predicate);
  public Boolean hasMatchingParentRef(Predicate<ParentReferenceBuilder> predicate);
  public A withParentRefs(List<ParentReference> parentRefs);
  public A withParentRefs(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ParentReference... parentRefs);
  public Boolean hasParentRefs();
  public HTTPRouteSpecFluent.ParentRefsNested<A> addNewParentRef();
  public HTTPRouteSpecFluent.ParentRefsNested<A> addNewParentRefLike(ParentReference item);
  public HTTPRouteSpecFluent.ParentRefsNested<A> setNewParentRefLike(int index,ParentReference item);
  public HTTPRouteSpecFluent.ParentRefsNested<A> editParentRef(int index);
  public HTTPRouteSpecFluent.ParentRefsNested<A> editFirstParentRef();
  public HTTPRouteSpecFluent.ParentRefsNested<A> editLastParentRef();
  public HTTPRouteSpecFluent.ParentRefsNested<A> editMatchingParentRef(Predicate<ParentReferenceBuilder> predicate);
  public A addToRules(int index,HTTPRouteRule item);
  public A setToRules(int index,HTTPRouteRule item);
  public A addToRules(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPRouteRule... items);
  public A addAllToRules(Collection<HTTPRouteRule> items);
  public A removeFromRules(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPRouteRule... items);
  public A removeAllFromRules(Collection<HTTPRouteRule> items);
  public A removeMatchingFromRules(Predicate<HTTPRouteRuleBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildRules instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<HTTPRouteRule> getRules();
  public List<HTTPRouteRule> buildRules();
  public HTTPRouteRule buildRule(int index);
  public HTTPRouteRule buildFirstRule();
  public HTTPRouteRule buildLastRule();
  public HTTPRouteRule buildMatchingRule(Predicate<HTTPRouteRuleBuilder> predicate);
  public Boolean hasMatchingRule(Predicate<HTTPRouteRuleBuilder> predicate);
  public A withRules(List<HTTPRouteRule> rules);
  public A withRules(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPRouteRule... rules);
  public Boolean hasRules();
  public HTTPRouteSpecFluent.RulesNested<A> addNewRule();
  public HTTPRouteSpecFluent.RulesNested<A> addNewRuleLike(HTTPRouteRule item);
  public HTTPRouteSpecFluent.RulesNested<A> setNewRuleLike(int index,HTTPRouteRule item);
  public HTTPRouteSpecFluent.RulesNested<A> editRule(int index);
  public HTTPRouteSpecFluent.RulesNested<A> editFirstRule();
  public HTTPRouteSpecFluent.RulesNested<A> editLastRule();
  public HTTPRouteSpecFluent.RulesNested<A> editMatchingRule(Predicate<HTTPRouteRuleBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ParentRefsNested<N> extends Nested<N>,ParentReferenceFluent<HTTPRouteSpecFluent.ParentRefsNested<N>>{
    public N and();
    public N endParentRef();
    
  }
  public interface RulesNested<N> extends Nested<N>,HTTPRouteRuleFluent<HTTPRouteSpecFluent.RulesNested<N>>{
    public N and();
    public N endRule();
    
  }
  
}
